==> elytratrims-fabric-3.9.2%2B1.20.1-sources.jar: dev/kikugie/elytratrims/mixin/compat/render/ElytraTrinketMixin.java <==
package dev.kikugie.elytratrims.mixin.compat.render;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import dev.kikugie.elytratrims.api.ElytraTrimsAPI;
import dev.kikugie.elytratrims.mixin.constants.Targets;
import me.fallenbreath.conditionalmixin.api.annotation.Condition;
import me.fallenbreath.conditionalmixin.api.annotation.Restriction;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_563;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.injection.At;

@Pseudo
@SuppressWarnings({"UnresolvedMixinReference", "rawtypes", "LocalMayBeArgsOnly"})
@Restriction(require = {@Condition("elytra_trinket")})
@Mixin(targets = "pw.lakuna.elytra_trinket.ElytraTrinketFeatureRenderer")
public abstract class ElytraTrinketMixin extends class_3887 {
    public ElytraTrinketMixin(class_3883 context) {
        super(context);
    }

    @ModifyExpressionValue(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/network/AbstractClientPlayerEntity;isPartVisible(Lnet/minecraft/client/render/entity/PlayerModelPart;)Z"))
    private boolean elytra_trinket$cancelCapeRender(boolean original, @Local(argsOnly = true) class_1309 entity) {
        return ElytraTrimsAPI.shouldShowCape(entity) && original;
    }

    @WrapOperation(method = "render", at = @At(value = "INVOKE", target = Targets.renderModel))
    private void elytra_trinket$elytraPostRender(
            class_563<?> model,
            class_4587 matrices,
            class_4588 vertices,
            int light,
            int overlay,
            //? if <1.21 {
            float red,
            float green,
            float blue,
            float alpha,
            //?}
            Operation<Void> operation,
            @Local(argsOnly = true) class_4597 provider,
            @Local(argsOnly = true) class_1309 entity,
            @Local class_1799 stack) {
        //$ render_call {
        operation.call(model, matrices, vertices, light, overlay, red, green, blue, alpha);
        ElytraTrimsAPI.renderFeatures(model, matrices, provider, entity, stack, light, red, green, blue, alpha);//$}
    }
}

==> elytratrims-fabric-3.9.3%2B1.21.1-sources.jar: dev/kikugie/elytratrims/mixin/compat/render/ElytraTrinketMixin.java <==
package dev.kikugie.elytratrims.mixin.compat.render;

import com.llamalad7.mixinextras.injector.ModifyExpressionValue;
import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import com.llamalad7.mixinextras.sugar.Local;
import dev.kikugie.elytratrims.api.ElytraTrimsAPI;
import dev.kikugie.elytratrims.mixin.constants.Targets;
import me.fallenbreath.conditionalmixin.api.annotation.Condition;
import me.fallenbreath.conditionalmixin.api.annotation.Restriction;
import net.minecraft.class_1309;
import net.minecraft.class_1799;
import net.minecraft.class_3883;
import net.minecraft.class_3887;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_4597;
import net.minecraft.class_563;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Pseudo;
import org.spongepowered.asm.mixin.injection.At;

@Pseudo
@SuppressWarnings({"UnresolvedMixinReference", "rawtypes", "LocalMayBeArgsOnly"})
@Restriction(require = {@Condition("elytra_trinket")})
@Mixin(targets = "pw.lakuna.elytra_trinket.ElytraTrinketFeatureRenderer")
public abstract class ElytraTrinketMixin extends class_3887 {
    public ElytraTrinketMixin(class_3883 context) {
        super(context);
    }

    @ModifyExpressionValue(method = "render", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/network/AbstractClientPlayerEntity;isPartVisible(Lnet/minecraft/client/render/entity/PlayerModelPart;)Z"))
    private boolean elytra_trinket$cancelCapeRender(boolean original, @Local(argsOnly = true) class_1309 entity) {
        return ElytraTrimsAPI.shouldShowCape(entity) && original;
    }

    @WrapOperation(method = "render", at = @At(value = "INVOKE", target = Targets.renderModel))
    private void elytra_trinket$elytraPostRender(
            class_563<?> model,
            class_4587 matrices,
            class_4588 vertices,
            int light,
            int overlay,
            //? if <1.21 {
            /*float red,
            float green,
            float blue,
            float alpha,
            *///?}
            Operation<Void> operation,
            @Local(argsOnly = true) class_4597 provider,
            @Local(argsOnly = true) class_1309 entity,
            @Local class_1799 stack) {
        //$ render_call {
        operation.call(model, matrices, vertices, light, overlay);
        ElytraTrimsAPI.renderFeatures(model, matrices, provider, entity, stack, light, -1);//$}
    }
}
